@@ -3,7 +3,7 @@ package Net::DNS::Header;
 use strict;
 use warnings;
 
-our $VERSION = (qw$Id: Header.pm 1886 2022-12-20 11:27:25Z willem $)[2];
+our $VERSION = (qw$Id: Header.pm 1895 2023-01-16 13:38:08Z willem $)[2];
 
 
 =head1 NAME
@@ -66,16 +66,11 @@ sub string {
 	my $an	   = $self->ancount;
 	my $ns	   = $self->nscount;
 	my $ar	   = $self->arcount;
-
-	my $opt	 = $$self->edns;
-	my $edns = $opt->_specified ? $opt->string : '';
-
-	return <<END . $edns if $opcode eq 'UPDATE';
+	return <<"QQ" if $opcode eq 'UPDATE';
 ;;	id = $id
 ;;	qr = $qr		opcode = $opcode	rcode = $rcode
 ;;	zocount = $qd	prcount = $an	upcount = $ns	adcount = $ar
-END
-
+QQ
 	my $aa = $self->aa;
 	my $tc = $self->tc;
 	my $rd = $self->rd;
@@ -84,14 +79,13 @@ END
 	my $ad = $self->ad;
 	my $cd = $self->cd;
 	my $do = $self->do;
-
-	return <<END . $edns;
+	return <<"QQ";
 ;;	id = $id
 ;;	qr = $qr	aa = $aa	tc = $tc	rd = $rd	opcode = $opcode
 ;;	ra = $ra	z  = $zz	ad = $ad	cd = $cd	rcode  = $rcode
 ;;	qdcount = $qd	ancount = $an	nscount = $ns	arcount = $ar
 ;;	do = $do
-END
+QQ
 }
 
 
@@ -123,8 +117,9 @@ A random value is assigned if the argument value is undefined.
 my ( $cache1, $cache2, $limit );				# two layer cache
 
 sub id {
-	my $self  = shift;
-	my $ident = scalar(@_) ? ( $$self->{id} = shift ) : $$self->{id};
+	my ( $self, @value ) = @_;
+	for (@value) { $$self->{id} = $_ }
+	my $ident = $$self->{id};
 	return $ident if $ident;
 	$ident = int rand(0xffff);				# preserve short-term uniqueness
 	$ident = int rand(0xffff) while $cache1->{$ident}++ + exists( $cache2->{$ident} );
@@ -192,7 +187,8 @@ Gets or sets the query response flag.
 =cut
 
 sub qr {
-	return shift->_dnsflag( 0x8000, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x8000, @value );
 }
 
 
@@ -206,7 +202,8 @@ Gets or sets the authoritative answer flag.
 =cut
 
 sub aa {
-	return shift->_dnsflag( 0x0400, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0400, @value );
 }
 
 
@@ -220,7 +217,8 @@ Gets or sets the truncated packet flag.
 =cut
 
 sub tc {
-	return shift->_dnsflag( 0x0200, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0200, @value );
 }
 
 
@@ -234,7 +232,8 @@ Gets or sets the recursion desired flag.
 =cut
 
 sub rd {
-	return shift->_dnsflag( 0x0100, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0100, @value );
 }
 
 
@@ -248,7 +247,8 @@ Gets or sets the recursion available flag.
 =cut
 
 sub ra {
-	return shift->_dnsflag( 0x0080, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0080, @value );
 }
 
 
@@ -259,7 +259,8 @@ Unassigned bit, should always be zero.
 =cut
 
 sub z {
-	return shift->_dnsflag( 0x0040, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0040, @value );
 }
 
 
@@ -276,7 +277,8 @@ and is allowed to set the bit by policy.)
 =cut
 
 sub ad {
-	return shift->_dnsflag( 0x0020, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0020, @value );
 }
 
 
@@ -290,7 +292,8 @@ Gets or sets the checking disabled flag.
 =cut
 
 sub cd {
-	return shift->_dnsflag( 0x0010, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_dnsflag( 0x0010, @value );
 }
 
 
@@ -307,10 +310,9 @@ to the number of RRs in the zone section.
 our $warned;
 
 sub qdcount {
-	my $self = shift;
-	return $$self->{count}[0] || scalar @{$$self->{question}} unless scalar @_;
-	carp 'packet->header->qdcount attribute is read-only'	  unless $warned++;
-	return;
+	my ( $self, @value ) = @_;
+	for (@value) { carp 'packet->header->qdcount attribute is read-only' unless $warned++ }
+	return $$self->{count}[0] || scalar @{$$self->{question}};
 }
 
 
@@ -327,10 +329,9 @@ to the number of RRs in the prerequisite section.
 =cut
 
 sub ancount {
-	my $self = shift;
-	return $$self->{count}[1] || scalar @{$$self->{answer}} unless scalar @_;
-	carp 'packet->header->ancount attribute is read-only'	unless $warned++;
-	return;
+	my ( $self, @value ) = @_;
+	for (@value) { carp 'packet->header->ancount attribute is read-only' unless $warned++ }
+	return $$self->{count}[1] || scalar @{$$self->{answer}};
 }
 
 
@@ -347,10 +348,9 @@ to the number of RRs in the update section.
 =cut
 
 sub nscount {
-	my $self = shift;
-	return $$self->{count}[2] || scalar @{$$self->{authority}} unless scalar @_;
-	carp 'packet->header->nscount attribute is read-only'	   unless $warned++;
-	return;
+	my ( $self, @value ) = @_;
+	for (@value) { carp 'packet->header->nscount attribute is read-only' unless $warned++ }
+	return $$self->{count}[2] || scalar @{$$self->{authority}};
 }
 
 
@@ -366,10 +366,9 @@ In dynamic update packets, this field is known as C<adcount>.
 =cut
 
 sub arcount {
-	my $self = shift;
-	return $$self->{count}[3] || scalar @{$$self->{additional}} unless scalar @_;
-	carp 'packet->header->arcount attribute is read-only'	    unless $warned++;
-	return;
+	my ( $self, @value ) = @_;
+	for (@value) { carp 'packet->header->arcount attribute is read-only' unless $warned++ }
+	return $$self->{count}[3] || scalar @{$$self->{additional}};
 }
 
 sub zocount { return &qdcount; }
@@ -391,7 +390,8 @@ Gets or sets the EDNS DNSSEC OK flag.
 =cut
 
 sub do {
-	return shift->_ednsflag( 0x8000, @_ );
+	my ( $self, @value ) = @_;
+	return $self->_ednsflag( 0x8000, @value );
 }
 
 
@@ -414,8 +414,8 @@ an EDNS feature.  Endless debate is avoided by supporting both views.
 =cut
 
 sub size {
-	my $self = shift;
-	return $$self->edns->size(@_);
+	my ( $self, @value ) = @_;
+	return $$self->edns->size(@value);
 }
 
 
@@ -441,11 +441,10 @@ sub edns {
 ########################################
 
 sub _dnsflag {
-	my $self = shift;
-	my $flag = shift;
+	my ( $self, $flag, @value ) = @_;
 	for ( $$self->{status} ) {
 		my $set = $_ | $flag;
-		$_ = (shift) ? $set : ( $set ^ $flag ) if scalar @_;
+		$_ = ( shift @value ) ? $set : ( $set ^ $flag ) if @value;
 		$flag &= $_;
 	}
 	return $flag ? 1 : 0;
@@ -453,12 +452,11 @@ sub _dnsflag {
 
 
 sub _ednsflag {
-	my $self = shift;
-	my $flag = shift;
+	my ( $self, $flag, @value ) = @_;
 	my $edns = $$self->edns;
 	for ( $edns->flags ) {
 		my $set = $_ | $flag;
-		$edns->flags( $_ = (shift) ? $set : ( $set ^ $flag ) ) if scalar @_;
+		$edns->flags( $_ = ( shift @value ) ? $set : ( $set ^ $flag ) ) if @value;
 		$flag &= $_;
 	}
 	return $flag ? 1 : 0;
@@ -503,7 +501,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::Packet>, L<Net::DNS::RR::OPT>,
+L<perl> L<Net::DNS> L<Net::DNS::Packet> L<Net::DNS::RR::OPT>
 L<RFC1035(4.1.1)|https://tools.ietf.org/html/rfc1035>
 
 =cut
