@@ -1,74 +1,69 @@
 package Net::DNS::RR::AFSDB;
 
-#
-# $Id: AFSDB.pm 1406 2015-10-05 08:25:49Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1406 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: AFSDB.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::AFSDB - DNS AFSDB resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, @argument ) = @_;
+	my ( $data, $offset, @opaque ) = @argument;
 
-	$self->{subtype} = unpack "\@$offset n", $$data;
-	$self->{hostname} = decode Net::DNS::DomainName2535( $data, $offset + 2, @opaque );
+	$self->{subtype}  = unpack "\@$offset n", $$data;
+	$self->{hostname} = Net::DNS::DomainName2535->decode( $data, $offset + 2, @opaque );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self,   @argument ) = @_;
+	my ( $offset, @opaque )	  = @argument;
 
-	my $hostname = $self->{hostname} || return '';
-	pack 'n a*', $self->subtype, $hostname->encode( $offset + 2, @opaque );
+	my $hostname = $self->{hostname};
+	return pack 'n a*', $self->subtype, $hostname->encode( $offset + 2, @opaque );
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $hostname = $self->{hostname} || return '';
-	join ' ', $self->subtype, $hostname->string;
+	my $hostname = $self->{hostname};
+	return join ' ', $self->subtype, $hostname->string;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->subtype(shift);
-	$self->hostname(shift);
+	for (qw(subtype hostname)) { $self->$_( shift @argument ) }
+	return;
 }
 
 
 sub subtype {
-	my $self = shift;
-
-	$self->{subtype} = 0 + shift if scalar @_;
-	$self->{subtype} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{subtype} = 0 + $_ }
+	return $self->{subtype} || 0;
 }
 
 
 sub hostname {
-	my $self = shift;
-
-	$self->{hostname} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{hostname}->name if $self->{hostname};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{hostname} = Net::DNS::DomainName2535->new($_) }
+	return $self->{hostname} ? $self->{hostname}->name : undef;
 }
 
 
@@ -79,7 +74,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name AFSDB subtype hostname');
+    $rr = Net::DNS::RR->new('name AFSDB subtype hostname');
 
 =head1 DESCRIPTION
 
@@ -127,7 +122,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -144,6 +139,8 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1183, RFC5864
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1183(1)|https://tools.ietf.org/html/rfc1183>
+L<RFC5864|https://tools.ietf.org/html/rfc5864>
 
 =cut
