@@ -1,75 +1,69 @@
 package Net::DNS::RR::KX;
 
-#
-# $Id: KX.pm 1382 2015-08-26 20:39:33Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1382 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: KX.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::KX - DNS KX resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, @argument ) = @_;
+	my ( $data, $offset, @opaque ) = @argument;
 
 	$self->{preference} = unpack( "\@$offset n", $$data );
-	$self->{exchange} = decode Net::DNS::DomainName2535( $data, $offset + 2, @opaque );
+	$self->{exchange}   = Net::DNS::DomainName2535->decode( $data, $offset + 2, @opaque );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self,   @argument ) = @_;
+	my ( $offset, @opaque )	  = @argument;
 
-	return '' unless $self->{exchange};
-	my $rdata = pack 'n', $self->preference;
-	$rdata .= $self->{exchange}->encode( $offset + length($rdata), @opaque );
+	my $exchange = $self->{exchange};
+	return pack 'n a*', $self->preference, $exchange->encode( $offset + 2, @opaque );
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{exchange};
-	join ' ', $self->preference, $self->{exchange}->string;
+	my $exchange = $self->{exchange};
+	return join ' ', $self->preference, $exchange->string;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->preference(shift);
-	$self->exchange(shift);
+	for (qw(preference exchange)) { $self->$_( shift @argument ) }
+	return;
 }
 
 
 sub preference {
-	my $self = shift;
-
-	$self->{preference} = 0 + shift if scalar @_;
-	$self->{preference} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{preference} = 0 + $_ }
+	return $self->{preference} || 0;
 }
 
 
 sub exchange {
-	my $self = shift;
-
-	$self->{exchange} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{exchange}->name if defined wantarray && $self->{exchange};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{exchange} = Net::DNS::DomainName2535->new($_) }
+	return $self->{exchange} ? $self->{exchange}->name : undef;
 }
 
 
@@ -89,7 +83,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name KX preference exchange');
+    $rr = Net::DNS::RR->new('name KX preference exchange');
 
 =head1 DESCRIPTION
 
@@ -136,7 +130,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -153,6 +147,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2230
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC2230|https://tools.ietf.org/html/rfc2230>
 
 =cut
