@@ -1,91 +1,85 @@
 package Net::DNS::RR::PX;
 
-#
-# $Id: PX.pm 1528 2017-01-18 21:44:58Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: PX.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::PX - DNS PX resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, @argument ) = @_;
+	my ( $data, $offset, @opaque ) = @argument;
 
 	$self->{preference} = unpack( "\@$offset n", $$data );
-	( $self->{map822},  $offset ) = decode Net::DNS::DomainName2535( $data, $offset + 2, @opaque );
-	( $self->{mapx400}, $offset ) = decode Net::DNS::DomainName2535( $data, $offset + 0, @opaque );
+	( $self->{map822},  $offset ) = Net::DNS::DomainName2535->decode( $data, $offset + 2, @opaque );
+	( $self->{mapx400}, $offset ) = Net::DNS::DomainName2535->decode( $data, $offset + 0, @opaque );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self,   @argument ) = @_;
+	my ( $offset, @opaque )	  = @argument;
 
-	my $mapx400 = $self->{mapx400} || return '';
-	my $rdata = pack( 'n', $self->{preference} );
+	my $mapx400 = $self->{mapx400};
+	my $rdata   = pack( 'n', $self->{preference} );
 	$rdata .= $self->{map822}->encode( $offset + 2, @opaque );
 	$rdata .= $mapx400->encode( $offset + length($rdata), @opaque );
+	return $rdata;
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $mapx400 = $self->{mapx400} || return '';
-	join ' ', $self->preference, $self->{map822}->string, $mapx400->string;
+	my @rdata = ( $self->preference, $self->{map822}->string, $self->{mapx400}->string );
+	return @rdata;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->preference(shift);
-	$self->map822(shift);
-	$self->mapx400(shift);
+	for (qw(preference map822 mapx400)) { $self->$_( shift @argument ) }
+	return;
 }
 
 
 sub preference {
-	my $self = shift;
-
-	$self->{preference} = 0 + shift if scalar @_;
-	$self->{preference} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{preference} = 0 + $_ }
+	return $self->{preference} || 0;
 }
 
 
 sub map822 {
-	my $self = shift;
-
-	$self->{map822} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{map822}->name if $self->{map822};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{map822} = Net::DNS::DomainName2535->new($_) }
+	return $self->{map822} ? $self->{map822}->name : undef;
 }
 
 
 sub mapx400 {
-	my $self = shift;
-
-	$self->{mapx400} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{mapx400}->name if $self->{mapx400};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{mapx400} = Net::DNS::DomainName2535->new($_) }
+	return $self->{mapx400} ? $self->{mapx400}->name : undef;
 }
 
 
 my $function = sub {			## sort RRs in numerically ascending order.
-	$Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'};
+	return $Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'};
 };
 
 __PACKAGE__->set_rrsort_func( 'preference', $function );
@@ -100,7 +94,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name PX preference map822 mapx400');
+    $rr = Net::DNS::RR->new('name PX preference map822 mapx400');
 
 =head1 DESCRIPTION
 
@@ -156,7 +150,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -173,6 +167,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2163
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC2163|https://tools.ietf.org/html/rfc2163>
 
 =cut
