@@ -1,22 +1,18 @@
 package Net::DNS::RR::RP;
 
-#
-# $Id: RP.pm 1382 2015-08-26 20:39:33Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1382 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: RP.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::RP - DNS RP resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
@@ -24,53 +20,53 @@ use Net::DNS::Mailbox;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, @argument ) = @_;
+	my ( $data, $offset, @opaque ) = @argument;
 
-	( $self->{mbox}, $offset ) = decode Net::DNS::Mailbox2535( $data, $offset, @opaque );
-	$self->{txtdname} = decode Net::DNS::DomainName2535( $data, $offset, @opaque );
+	( $self->{mbox}, $offset ) = Net::DNS::Mailbox2535->decode( $data, $offset, @opaque );
+	$self->{txtdname} = Net::DNS::DomainName2535->decode( $data, $offset, @opaque );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self,   @argument ) = @_;
+	my ( $offset, @opaque )	  = @argument;
 
-	return '' unless $self->{txtdname};
-	my $rdata = $self->{mbox}->encode( $offset, @opaque );
-	$rdata .= $self->{txtdname}->encode( $offset + length($rdata), @opaque );
+	my $txtdname = $self->{txtdname};
+	my $rdata    = $self->{mbox}->encode( $offset, @opaque );
+	$rdata .= $txtdname->encode( $offset + length($rdata), @opaque );
+	return $rdata;
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{mbox};
-	join ' ', map $self->{$_}->string, qw(mbox txtdname);
+	my @rdata = ( $self->{mbox}->string, $self->{txtdname}->string );
+	return @rdata;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->mbox(shift);
-	$self->txtdname(shift);
+	for (qw(mbox txtdname)) { $self->$_( shift @argument ) }
+	return;
 }
 
 
 sub mbox {
-	my $self = shift;
-
-	$self->{mbox} = new Net::DNS::Mailbox2535(shift) if scalar @_;
-	$self->{mbox}->address if defined wantarray && $self->{mbox};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{mbox} = Net::DNS::Mailbox2535->new($_) }
+	return $self->{mbox} ? $self->{mbox}->address : undef;
 }
 
 
 sub txtdname {
-	my $self = shift;
-
-	$self->{txtdname} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{txtdname}->name if defined wantarray && $self->{txtdname};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{txtdname} = Net::DNS::DomainName2535->new($_) }
+	return $self->{txtdname} ? $self->{txtdname}->name : undef;
 }
 
 
@@ -81,7 +77,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name RP mbox txtdname');
+    $rr = Net::DNS::RR->new('name RP mbox txtdname');
 
 =head1 DESCRIPTION
 
@@ -133,7 +129,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -150,6 +146,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1183 Section 2.2
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1183(2.2)|https://tools.ietf.org/html/rfc1183>
 
 =cut
