@@ -1,100 +1,95 @@
 package Net::DNS::RR::SRV;
 
-#
-# $Id: SRV.pm 1382 2015-08-26 20:39:33Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1382 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: SRV.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::SRV - DNS SRV resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, @argument ) = @_;
+	my ( $data, $offset, @opaque ) = @argument;
 
 	@{$self}{qw(priority weight port)} = unpack( "\@$offset n3", $$data );
 
-	$self->{target} = decode Net::DNS::DomainName2535( $data, $offset + 6, @opaque );
+	$self->{target} = Net::DNS::DomainName2535->decode( $data, $offset + 6, @opaque );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self,   @argument ) = @_;
+	my ( $offset, @opaque )	  = @argument;
 
-	return '' unless $self->{target};
-	my $nums = pack 'n3', $self->priority, $self->weight, $self->port;
-	$nums .= $self->{target}->encode( $offset + length($nums), @opaque );
+	my $target = $self->{target};
+	my @nums   = ( $self->priority, $self->weight, $self->port );
+	return pack 'n3 a*', @nums, $target->encode( $offset + 6, @opaque );
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{target};
-	my @rdata = $self->priority, $self->weight, $self->port, $self->{target}->string;
+	my $target = $self->{target};
+	my @rdata  = ( $self->priority, $self->weight, $self->port, $target->string );
+	return @rdata;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
 	foreach my $attr (qw(priority weight port target)) {
-		$self->$attr(shift);
+		$self->$attr( shift @argument );
 	}
+	return;
 }
 
 
 sub priority {
-	my $self = shift;
-
-	$self->{priority} = 0 + shift if scalar @_;
-	$self->{priority} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{priority} = 0 + $_ }
+	return $self->{priority} || 0;
 }
 
 
 sub weight {
-	my $self = shift;
-
-	$self->{weight} = 0 + shift if scalar @_;
-	$self->{weight} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{weight} = 0 + $_ }
+	return $self->{weight} || 0;
 }
 
 
 sub port {
-	my $self = shift;
-
-	$self->{port} = 0 + shift if scalar @_;
-	$self->{port} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{port} = 0 + $_ }
+	return $self->{port} || 0;
 }
 
 
 sub target {
-	my $self = shift;
-
-	$self->{target} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{target}->name if defined wantarray && $self->{target};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{target} = Net::DNS::DomainName2535->new($_) }
+	return $self->{target} ? $self->{target}->name : undef;
 }
 
 
 # order RRs by numerically increasing priority, decreasing weight
 my $function = sub {
 	my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
-	$a->{priority} <=> $b->{priority}
+	return $a->{priority} <=> $b->{priority}
 			|| $b->{weight} <=> $a->{weight};
 };
 
@@ -110,7 +105,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name SRV priority weight port target');
+    $rr = Net::DNS::RR->new('name SRV priority weight port target');
 
 =head1 DESCRIPTION
 
@@ -177,7 +172,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -194,6 +189,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2782
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC2782|https://tools.ietf.org/html/rfc2782>
 
 =cut
